@@ -20,10 +20,6 @@
 
 #include "audioView2.h"
 #include "ui_audioView2.h"
-
-#include <KGlobalSettings>
-#include <KFontSizeAction>
-
 #include "theStream.h"
 #include "videoWindow.h"
 
@@ -38,13 +34,6 @@ AudioView2::AudioView2(QWidget *parent) :
     ui->m_analyzerFrame->setMaximumSize(ui->m_analyzer->maximumSize());
     ui->m_analyzerFrame->setMinimumSize(ui->m_analyzer->minimumSize());
 
-    QFont boldFont = KGlobalSettings::generalFont();
-    boldFont.setBold(true);
-    ui->m_track->setFont(boldFont);
-    ui->m_artist->setFont(KGlobalSettings::generalFont());
-    ui->m_album->setFont(KGlobalSettings::generalFont());
-
-    engine()->setupAnalyzer(ui->m_analyzer);
     connect(engine(), SIGNAL(metaDataChanged()), this, SLOT(update()));
 }
 
@@ -53,6 +42,11 @@ AudioView2::~AudioView2()
     delete ui;
 }
 
+void AudioView2::setupAnalyzer()
+{
+    engine()->setupAnalyzer(ui->m_analyzer);
+}
+
 void AudioView2::enableDemo(bool enable)
 {
     ui->m_analyzer->enableDemo(enable);
@@ -63,30 +57,30 @@ void AudioView2::update()
     ui->m_artist->setText( TheStream::metaData( Phonon::ArtistMetaData ) );
     ui->m_album->setText( TheStream::metaData( Phonon::AlbumMetaData ) );
     ui->m_track->setText( TheStream::metaData( Phonon::TitleMetaData ) );
-//    { //somewhat of a longshot: try to find Amarok cover for the music
-//        QString imagePath = checkForAmarokImage( artist, album );
-//        if(imagePath.isNull())
-//        {
-//            delete m_image;
-//            m_image = 0;
-//            m_layout->setColumnFixedWidth(0, 0.0);
-//        }
-//        else
-//        {
-//            m_layout->setColumnFixedWidth(0, COVER_COLUMN_WIDTH);
-//            if(!m_image)
-//            {
-//                m_image = new QGraphicsPixmapItem();
-//                scene()->addItem( m_image );
-//                m_image->setPos( 3.0, 3.0 );
-//            }
-//            QPixmap cover( imagePath );
-//            m_image->setPixmap( cover );
-//            qreal width = static_cast<qreal>( cover.width() );
-//            qreal scale = COVER_WIDTH / width;
-//            m_image->setScale( scale );
-//        }
-//    }
+    //    { //somewhat of a longshot: try to find Amarok cover for the music
+    //        QString imagePath = checkForAmarokImage( artist, album );
+    //        if(imagePath.isNull())
+    //        {
+    //            delete m_image;
+    //            m_image = 0;
+    //            m_layout->setColumnFixedWidth(0, 0.0);
+    //        }
+    //        else
+    //        {
+    //            m_layout->setColumnFixedWidth(0, COVER_COLUMN_WIDTH);
+    //            if(!m_image)
+    //            {
+    //                m_image = new QGraphicsPixmapItem();
+    //                scene()->addItem( m_image );
+    //                m_image->setPos( 3.0, 3.0 );
+    //            }
+    //            QPixmap cover( imagePath );
+    //            m_image->setPixmap( cover );
+    //            qreal width = static_cast<qreal>( cover.width() );
+    //            qreal scale = COVER_WIDTH / width;
+    //            m_image->setScale( scale );
+    //        }
+    //    }
 }
 
 
